clear

set excelxlsxlargefile on // To deal with large Excel files on some versions of Stata

* Import and clean Round 1 data
*******************************

import excel using "Data/Source/presi_2012_communes_t1_t2.xls", sheet("Tour 1") firstrow allstring clear

keep Codedudpartement Libelldudpartement Inscrits Votants Exprims AE BU

ren AE votes_Sarkozy
ren BU votes_Hollande

destring Inscrits-votes_Hollande, replace

collapse (sum) Inscrits-votes_Hollande, by(Codedudpartement Libelldudpartement) fast
* Sum by dpartement

foreach var of varlist Inscrits-votes_Hollande{
ren `var' `var'_1
}
*

save "Data/Temp/round1", replace

* Import and clean Round 2 data
*******************************

import excel using "Data/Source/presi_2012_communes_t1_t2.xls", sheet("Tour 2") firstrow allstring clear

keep Codedudpartement Libelldudpartement Inscrits Votants Exprims Voix Y

ren Voix votes_Hollande
ren Y votes_Sarkozy

order votes_Hollande, last

destring Inscrits-votes_Hollande, replace

collapse (sum) Inscrits-votes_Hollande, by(Codedudpartement Libelldudpartement) fast
* Sum by dpartement

foreach var of varlist Inscrits-votes_Hollande{
ren `var' `var'_2
}
*

* Merge both rounds
*******************

merge 1:1 Codedudpartement Libelldudpartement using "Data/Temp/round1"
drop _merge
erase "Data/Temp/round1.dta"

* Secondary data construction
*****************************
foreach i in 1 2{
gen turnout_`i' = Votants_`i'/ Inscrits_`i'
gen vote_share_hollande_`i' = votes_Hollande_`i' / Exprims_`i'
gen vote_share_sarkozy_`i' = votes_Sarkozy_`i' / Exprims_`i'
}
*

gen change_hollande = vote_share_hollande_2 - vote_share_hollande_1
gen change_sarkozy = vote_share_sarkozy_2 - vote_share_sarkozy_1

keep Codedudpartement Libelldudpartement turnout_1-change_sarkozy

* Saving
********

save "Data/Final/2012_presi", replace

